@@ -101,6 +101,7 @@ else: # called as script
     import utils
     import LossHistory
 
+from gc import collect
 
 from keras import backend as K
 
@@ -2108,6 +2109,8 @@ class DeepSR(object):
 
                         self.plot_layer_weights(saveimages=self.saveimages,name=name, plot=False, dpi=300)
 
+                    collect() # garbage collector
+
             # write results in an excel file in weight folder
             excel_file = self.modelname + '_' + test_name + "_results_scale_" + text_scale + ".xlsx"
 
